==> huaweicloudsdkdws-3.1.131-py2.py3-none-any.whl: huaweicloudsdkdws/v2/model/list_snapshot_cross_region_policy_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListSnapshotCrossRegionPolicyResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'cross_region_configs': 'list[CrossRegionSnapshotConfig]',
        'count': 'int'
    }

    attribute_map = {
        'cross_region_configs': 'cross_region_configs',
        'count': 'count'
    }

    def __init__(self, cross_region_configs=None, count=None):
        """ListSnapshotCrossRegionPolicyResponse

        The model defined in huaweicloud sdk

        :param cross_region_configs: 跨区域配置信息
        :type cross_region_configs: list[:class:`huaweicloudsdkdws.v2.CrossRegionSnapshotConfig`]
        :param count: 总数
        :type count: int
        """
        
        super(ListSnapshotCrossRegionPolicyResponse, self).__init__()

        self._cross_region_configs = None
        self._count = None
        self.discriminator = None

        if cross_region_configs is not None:
            self.cross_region_configs = cross_region_configs
        if count is not None:
            self.count = count

    @property
    def cross_region_configs(self):
        """Gets the cross_region_configs of this ListSnapshotCrossRegionPolicyResponse.

        跨区域配置信息

        :return: The cross_region_configs of this ListSnapshotCrossRegionPolicyResponse.
        :rtype: list[:class:`huaweicloudsdkdws.v2.CrossRegionSnapshotConfig`]
        """
        return self._cross_region_configs

    @cross_region_configs.setter
    def cross_region_configs(self, cross_region_configs):
        """Sets the cross_region_configs of this ListSnapshotCrossRegionPolicyResponse.

        跨区域配置信息

        :param cross_region_configs: The cross_region_configs of this ListSnapshotCrossRegionPolicyResponse.
        :type cross_region_configs: list[:class:`huaweicloudsdkdws.v2.CrossRegionSnapshotConfig`]
        """
        self._cross_region_configs = cross_region_configs

    @property
    def count(self):
        """Gets the count of this ListSnapshotCrossRegionPolicyResponse.

        总数

        :return: The count of this ListSnapshotCrossRegionPolicyResponse.
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """Sets the count of this ListSnapshotCrossRegionPolicyResponse.

        总数

        :param count: The count of this ListSnapshotCrossRegionPolicyResponse.
        :type count: int
        """
        self._count = count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListSnapshotCrossRegionPolicyResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdws-3.1.147-py2.py3-none-any.whl: huaweicloudsdkdws/v2/model/list_snapshot_cross_region_policy_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListSnapshotCrossRegionPolicyResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'cross_region_configs': 'list[CrossRegionSnapshotConfig]',
        'count': 'int'
    }

    attribute_map = {
        'cross_region_configs': 'cross_region_configs',
        'count': 'count'
    }

    def __init__(self, cross_region_configs=None, count=None):
        r"""ListSnapshotCrossRegionPolicyResponse

        The model defined in huaweicloud sdk

        :param cross_region_configs: 跨区域配置信息
        :type cross_region_configs: list[:class:`huaweicloudsdkdws.v2.CrossRegionSnapshotConfig`]
        :param count: 总数
        :type count: int
        """
        
        super(ListSnapshotCrossRegionPolicyResponse, self).__init__()

        self._cross_region_configs = None
        self._count = None
        self.discriminator = None

        if cross_region_configs is not None:
            self.cross_region_configs = cross_region_configs
        if count is not None:
            self.count = count

    @property
    def cross_region_configs(self):
        r"""Gets the cross_region_configs of this ListSnapshotCrossRegionPolicyResponse.

        跨区域配置信息

        :return: The cross_region_configs of this ListSnapshotCrossRegionPolicyResponse.
        :rtype: list[:class:`huaweicloudsdkdws.v2.CrossRegionSnapshotConfig`]
        """
        return self._cross_region_configs

    @cross_region_configs.setter
    def cross_region_configs(self, cross_region_configs):
        r"""Sets the cross_region_configs of this ListSnapshotCrossRegionPolicyResponse.

        跨区域配置信息

        :param cross_region_configs: The cross_region_configs of this ListSnapshotCrossRegionPolicyResponse.
        :type cross_region_configs: list[:class:`huaweicloudsdkdws.v2.CrossRegionSnapshotConfig`]
        """
        self._cross_region_configs = cross_region_configs

    @property
    def count(self):
        r"""Gets the count of this ListSnapshotCrossRegionPolicyResponse.

        总数

        :return: The count of this ListSnapshotCrossRegionPolicyResponse.
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        r"""Sets the count of this ListSnapshotCrossRegionPolicyResponse.

        总数

        :param count: The count of this ListSnapshotCrossRegionPolicyResponse.
        :type count: int
        """
        self._count = count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListSnapshotCrossRegionPolicyResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
